@@ -9,6 +9,8 @@ import os
 import subprocess
 import time
 
+import pytest
+
 import samltest
 
 
@@ -34,22 +36,25 @@ class move_idp_metadata:
         restart_umc()
 
 
+@pytest.fixture(autouse=True)
+def cleanup():
+    yield
+    restart_umc()
+
+
 def test_broken_idp_metadata(saml_session):
-    try:
-        with move_idp_metadata():
-            try:
-                saml_session.login_with_new_session_at_IdP()
-            except samltest.SamlError as exc:
-                expected_error = "There is a configuration error in the service provider: No identity provider are set up for use."
-                if expected_error not in str(exc):
-                    raise Exception({'expected': expected_error, 'got': str(exc)})
-        saml_session.logout_at_IdP()
-        saml_session.login_with_new_session_at_IdP()
-        saml_session.test_logged_in_status()
-        saml_session.logout_at_IdP()
-        saml_session.test_logout_at_IdP()
-        saml_session.test_logout()
-    finally:
-        # Make sure everything is in a working state again
-        restart_umc()
-    print("####Success: UMC server does not stop if the idp metadata is not available.####")
+    with move_idp_metadata():
+        try:
+            saml_session.login_with_new_session_at_IdP()
+        except samltest.SamlError as exc:
+            expected_error = "There is a configuration error in the service provider: No identity provider are set up for use."
+            if expected_error not in str(exc):
+                raise Exception({'expected': expected_error, 'got': str(exc)})
+
+    saml_session.logout_at_IdP()
+
+    saml_session.login_with_new_session_at_IdP()
+    saml_session.test_logged_in_status()
+    saml_session.logout_at_IdP()
+    saml_session.test_logout_at_IdP()
+    saml_session.test_logout()
