@@ -78,23 +78,6 @@ class UCSLanguage(Enum):
         return ""
 
 
-class Waits:
-    def __init__(self, page) -> None:
-        self.page: Page = page
-
-    def wait_for_text_to_be_visible(self, text: str, timeout: int = 1 * MIN):
-        """Waits for the specified text to be visible on screen"""
-        all_locators = self.page.get_by_text(text).all()
-        for locator in all_locators:
-            expect(locator).to_be_visible(timeout=timeout)
-
-    def wait_for_progress_bar(self, n: int = 1, timeout: int = 1 * MIN):
-        """Waits for `n` progress bars to disappear"""
-        for _ in range(n):
-            progress_bar = self.page.get_by_role("progressbar")
-            expect(progress_bar).to_be_hidden(timeout=timeout)
-
-
 class Interactions:
     def __init__(self, tester: UMCBrowserTest) -> None:
         self.tester: UMCBrowserTest = tester
@@ -197,7 +180,7 @@ class Interactions:
             from univention.testing.browser.appcenter import AppCenter, wait_for_final_query
 
             app_center = AppCenter(self.tester)
-            with self.page.expect_response(lambda request: wait_for_final_query(request)):
+            with self.page.expect_response(lambda request: wait_for_final_query(request), timeout=2 * MIN):
                 app_center.handle_first_open_dialog()
 
     def fill_combobox(self, name: str, option: str):
@@ -207,7 +190,7 @@ class Interactions:
         self.page.get_by_role("option", name=option).click()
 
 
-class UMCBrowserTest(Waits, Interactions):
+class UMCBrowserTest(Interactions):
     """
     This is the base class for all Playwright browser tests. It defines common operations and methods
     that are useful to all other library modules.
@@ -224,7 +207,6 @@ class UMCBrowserTest(Waits, Interactions):
     def __init__(self, page: Page, lang: UCSLanguage = UCSLanguage.EN_US):
         self.page: Page = page
         self.set_language(lang)
-        Waits.__init__(self, page)
         Interactions.__init__(self, self)
 
     def set_language(self, lang: UCSLanguage):
@@ -244,14 +226,15 @@ class UMCBrowserTest(Waits, Interactions):
         ]
 
         role = ucr.get("server/role")
+
         # if we are not on the master we also need to set the language cookie for the master
-        cookies.append(
-            {
+        if role != "domaincontroller_master":
+            cookies.append({
                 "name": "UMCLang",
                 "value": lang,
                 "url": f"https://{ucr.get('ldap/master')}/univention",
-            },
-        ) if role != "domaincontroller_master" else None
+            })
+
         self.page.context.add_cookies(cookies)
 
     @property
@@ -268,7 +251,6 @@ class UMCBrowserTest(Waits, Interactions):
         return ucr["domainname"]
 
     def check_for_no_module_available_popup(self):
-        # expect(self.page.get_by_role("dialog")).to_be_visible()
         popup = self.page.get_by_role("dialog").get_by_text("There is no module available for the authenticated user")
         expect(popup).to_be_visible(timeout=30 * SEC)
 
@@ -333,7 +315,6 @@ class UMCBrowserTest(Waits, Interactions):
             else:
                 with self.page.expect_response(join_script_query):
                     login_button.click()
-
         elif check_for_no_module_available_popup:
             login_button.click()
             logger.info("Checking for the 'No module for user available popup'")
@@ -342,6 +323,7 @@ class UMCBrowserTest(Waits, Interactions):
             logger.info("Logging in without waiting for requests to finish")
             login_button.click()
 
+        # TODO: wait_until networkidle is discouraged by Playwright, replace at some point
         self.page.wait_for_url(re.compile(r".*univention/(management|portal).*"), wait_until="networkidle")
         logging.info("Login Done")
 
@@ -367,4 +349,4 @@ class UMCBrowserTest(Waits, Interactions):
 
     def restart_umc(self):
         self.systemd_restart_service("univention-management-console-server")
-        time.sleep(5)
+        time.sleep(3)
